@@ -43,6 +43,41 @@ PROVIDER_LIST = [
 ]
 
 
+def common_options(func):
+    import functools
+
+    @click.option(
+        "--provider",
+        type=click.Choice(PROVIDER_LIST),
+        default=None,
+        help="LLM provider to use (claude, groq, openai, google, github_copilot, or deepinfra)",
+    )
+    @click.option(
+        "--agent-config",
+        default=None,
+        help="Path/URL to the agent configuration file.",
+    )
+    @click.option(
+        "--mcp-config", default=None, help="Path to the mcp servers configuration file."
+    )
+    @click.option(
+        "--memory-llm",
+        type=click.Choice(
+            ["claude", "groq", "openai", "google", "deepinfra", "github_copilot"]
+        ),
+        default=None,
+        help="LLM Model use for analyzing and processing memory",
+    )
+    @click.option(
+        "--memory-path", default=None, help="Path to the memory database location"
+    )
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        return func(*args, **kwargs)
+
+    return wrapper
+
+
 class AgentCrewApplication:
     """
     Centralized application class for AgentCrew.
@@ -584,7 +619,7 @@ tools = ["memory", "browser", "web_search", "code_analysis"]
                         "No LLM API key found. Please set either ANTHROPIC_API_KEY, GEMINI_API_KEY, OPENAI_API_KEY, GROQ_API_KEY, or DEEPINFRA_API_KEY"
                     )
 
-            services = self.setup_services(provider, memory_llm)
+            services = self.setup_services(provider, memory_llm, need_memory=False)
 
             if mcp_config:
                 os.environ["MCP_CONFIG_PATH"] = mcp_config
