@@ -27,6 +27,11 @@ from a2a.types import (
     TaskState,
     TaskStatusUpdateEvent,
     TaskArtifactUpdateEvent,
+    Part,
+    TextPart,
+    DataPart,
+    Role,
+    Message,
 )
 
 from AgentCrew.modules.agents import LocalAgent
@@ -58,6 +63,7 @@ class AgentTaskManager(TaskManager):
     """Manages tasks for a specific agent"""
 
     TERMINAL_STATES = {TaskState.completed, TaskState.canceled, TaskState.failed}
+    INPUT_REQUIRED_STATES = {TaskState.input_required}
 
     def __init__(self, agent_name: str, agent_manager: AgentManager):
         self.agent_name = agent_name
@@ -72,16 +78,32 @@ class AgentTaskManager(TaskManager):
         ] = defaultdict(list)
         self.streaming_enabled_tasks: set[str] = set()
 
+        self.pending_ask_responses: Dict[str, asyncio.Event] = {}
+        self.ask_responses: Dict[str, str] = {}
+
         self.agent = self.agent_manager.get_agent(self.agent_name)
         if self.agent is None or not isinstance(self.agent, LocalAgent):
             raise ValueError(f"Agent {agent_name} not found or is not a LocalAgent")
 
-        self.memory_service = self.agent.services["memory"]
+        self.memory_service = self.agent.services.get("memory", None)
 
     def _is_terminal_state(self, state: TaskState) -> bool:
         """Check if a state is terminal."""
         return state in self.TERMINAL_STATES
 
+    def _extract_text_from_message(self, message: Dict[str, Any]) -> str:
+        """Extract text content from a message."""
+        content = message.get("content", [])
+        if isinstance(content, str):
+            return content
+        text_parts = []
+        for part in content:
+            if isinstance(part, str):
+                text_parts.append(part)
+            elif isinstance(part, dict) and part.get("type") == "text":
+                text_parts.append(part.get("text", ""))
+        return " ".join(text_parts)
+
     def _validate_task_not_terminal(
         self, task: Task, operation: str
     ) -> Optional[TaskNotCancelableError]:
@@ -121,7 +143,6 @@ class AgentTaskManager(TaskManager):
                 )
             )
 
-        # Generate task ID from message
         task_id = (
             request.params.message.task_id
             or f"task_{request.params.message.message_id}"
@@ -135,8 +156,19 @@ class AgentTaskManager(TaskManager):
                     root=JSONRPCErrorResponse(id=request.id, error=error)
                 )
 
+            if existing_task.status.state == TaskState.input_required:
+                message = convert_a2a_message_to_agent(request.params.message)
+                user_response = self._extract_text_from_message(message)
+
+                if task_id in self.pending_ask_responses:
+                    self.ask_responses[task_id] = user_response
+                    self.pending_ask_responses[task_id].set()
+
+                return SendMessageResponse(
+                    root=SendMessageSuccessResponse(id=request.id, result=existing_task)
+                )
+
         if task_id not in self.tasks:
-            # Create task with initial state
             task = Task(
                 id=task_id,
                 context_id=request.params.message.context_id or f"ctx_{task_id}",
@@ -147,8 +179,8 @@ class AgentTaskManager(TaskManager):
             self.tasks[task.id] = task
 
         task = self.tasks[task_id]
-        if task_id not in self.task_history:
-            self.task_history[task_id] = []
+        if task.context_id not in self.task_history:
+            self.task_history[task.context_id] = []
 
         # Convert A2A message to SwissKnife format
         message = convert_a2a_message_to_agent(request.params.message)
@@ -185,9 +217,8 @@ class AgentTaskManager(TaskManager):
 
             message["content"] = new_parts
 
-        self.task_history[task_id].append(message)
+        self.task_history[task.context_id].append(message)
 
-        # Process with agent (non-blocking)
         asyncio.create_task(self._process_agent_task(self.agent, task))
 
         # Return initial task state
@@ -241,8 +272,38 @@ class AgentTaskManager(TaskManager):
 
         finally:
             # Clean up
+            self.tasks.pop(task_id, None)
             self.streaming_tasks.pop(task_id, None)
 
+    def _create_ask_tool_message(
+        self, question: str, guided_answers: list[str]
+    ) -> Message:
+        """
+        Create an A2A message for the ask tool's input-required state.
+
+        Args:
+            question: The question to ask the user
+            guided_answers: List of suggested answers
+
+        Returns:
+            A2A Message with the question and guided answers
+        """
+        ask_data = {
+            "type": "ask",
+            "question": question,
+            "guided_answers": guided_answers,
+            "instruction": "Please respond with one of the guided answers or provide a custom response.",
+        }
+
+        return Message(
+            message_id=f"ask_{hash(question)}",
+            role=Role.agent,
+            parts=[
+                Part(root=TextPart(text=f"❓ {question}")),
+                Part(root=DataPart(data=ask_data)),
+            ],
+        )
+
     def _record_and_emit_event(
         self, task_id: str, event: Union[TaskStatusUpdateEvent, TaskArtifactUpdateEvent]
     ):
@@ -281,7 +342,7 @@ class AgentTaskManager(TaskManager):
 
         try:
             artifacts = []
-            if task.id not in self.task_history:
+            if task.context_id not in self.task_history:
                 raise ValueError("Task history is not existed")
 
             input_tokens = 0
@@ -308,7 +369,7 @@ class AgentTaskManager(TaskManager):
                     chunk_text,
                     thinking_chunk,
                 ) in agent.process_messages(
-                    self.task_history[task.id], callback=process_result
+                    self.task_history[task.context_id], callback=process_result
                 ):
                     # Update current response
                     if response_message:
@@ -388,9 +449,8 @@ class AgentTaskManager(TaskManager):
                         MessageType.Thinking, {"thinking": thinking_data}
                     )
                     if thinking_message:
-                        self.task_history[task.id].append(thinking_message)
+                        self.task_history[task.context_id].append(thinking_message)
 
-                    # Format assistant message with the response and tool uses
                     assistant_message = agent.format_message(
                         MessageType.Assistant,
                         {
@@ -401,34 +461,99 @@ class AgentTaskManager(TaskManager):
                         },
                     )
                     if assistant_message:
-                        self.task_history[task.id].append(assistant_message)
+                        self.task_history[task.context_id].append(assistant_message)
 
-                    # Process each tool use
                     for tool_use in tool_uses:
-                        try:
-                            tool_result = await agent.execute_tool_call(
-                                tool_use["name"],
-                                tool_use["input"],
+                        tool_name = tool_use["name"]
+
+                        if tool_name == "ask":
+                            question = tool_use["input"].get("question", "")
+                            guided_answers = tool_use["input"].get("guided_answers", [])
+
+                            task.status.state = TaskState.input_required
+                            task.status.timestamp = datetime.now().isoformat()
+                            task.status.message = self._create_ask_tool_message(
+                                question, guided_answers
                             )
 
+                            self._record_and_emit_event(
+                                task.id,
+                                TaskStatusUpdateEvent(
+                                    task_id=task.id,
+                                    context_id=task.context_id,
+                                    status=task.status,
+                                    final=False,
+                                ),
+                            )
+
+                            wait_event = asyncio.Event()
+                            self.pending_ask_responses[task.id] = wait_event
+
+                            try:
+                                await asyncio.wait_for(wait_event.wait(), timeout=300)
+                                user_answer = self.ask_responses.get(
+                                    task.id, "No response received"
+                                )
+                            except asyncio.TimeoutError:
+                                user_answer = "User did not respond in time."
+                            finally:
+                                self.pending_ask_responses.pop(task.id, None)
+                                self.ask_responses.pop(task.id, None)
+
+                            tool_result = f"User's answer: {user_answer}"
+
+                            task.status.state = TaskState.working
+                            task.status.timestamp = datetime.now().isoformat()
+                            task.status.message = None
+
                             tool_result_message = agent.format_message(
                                 MessageType.ToolResult,
                                 {"tool_use": tool_use, "tool_result": tool_result},
                             )
                             if tool_result_message:
-                                self.task_history[task.id].append(tool_result_message)
+                                self.task_history[task.context_id].append(
+                                    tool_result_message
+                                )
 
-                        except Exception as e:
-                            error_message = agent.format_message(
-                                MessageType.ToolResult,
-                                {
-                                    "tool_use": tool_use,
-                                    "tool_result": str(e),
-                                    "is_error": True,
-                                },
+                            self._record_and_emit_event(
+                                task.id,
+                                TaskStatusUpdateEvent(
+                                    task_id=task.id,
+                                    context_id=task.context_id,
+                                    status=task.status,
+                                    final=False,
+                                ),
                             )
-                            if error_message:
-                                self.task_history[task.id].append(error_message)
+
+                        else:
+                            try:
+                                tool_result = await agent.execute_tool_call(
+                                    tool_name,
+                                    tool_use["input"],
+                                )
+
+                                tool_result_message = agent.format_message(
+                                    MessageType.ToolResult,
+                                    {"tool_use": tool_use, "tool_result": tool_result},
+                                )
+                                if tool_result_message:
+                                    self.task_history[task.context_id].append(
+                                        tool_result_message
+                                    )
+
+                            except Exception as e:
+                                error_message = agent.format_message(
+                                    MessageType.ToolResult,
+                                    {
+                                        "tool_use": tool_use,
+                                        "tool_result": str(e),
+                                        "is_error": True,
+                                    },
+                                )
+                                if error_message:
+                                    self.task_history[task.context_id].append(
+                                        error_message
+                                    )
 
                     return await _process_task()
                 return current_response
@@ -442,15 +567,16 @@ class AgentTaskManager(TaskManager):
                     },
                 )
                 if assistant_message:
-                    self.task_history[task.id].append(assistant_message)
+                    self.task_history[task.context_id].append(assistant_message)
                 user_message = (
-                    self.task_history[task.id][0]
+                    self.task_history[task.context_id][0]
                     .get("content", [{}])[0]
                     .get("text", "")
                 )
-                self.memory_service.store_conversation(
-                    user_message, current_response, self.agent_name
-                )
+                if self.memory_service:
+                    self.memory_service.store_conversation(
+                        user_message, current_response, self.agent_name
+                    )
 
             # Create artifact from final response
             artifact = convert_agent_response_to_a2a_artifact(
@@ -604,7 +730,7 @@ class AgentTaskManager(TaskManager):
         Yields:
             Streaming responses with task updates
         """
-        task_id = request.params.task_id
+        task_id = request.params.id
 
         if task_id not in self.tasks:
             error = A2AError.task_not_found(task_id)
