@@ -111,25 +111,25 @@ class LocalAgent(BaseAgent):
             # self.tool_prompts.append(
             #     delegate_tool_prompt(self.services["agent_manager"])
             # )
+            from AgentCrew.modules.agents.tools.ask import (
+                register as register_ask,
+                ask_tool_prompt,
+            )
+
+            register_ask(self)
+            self.tool_prompts.append(ask_tool_prompt())
+
             if not self.is_remoting_mode:
                 from AgentCrew.modules.agents.tools.transfer import (
                     register as register_transfer,
                     transfer_tool_prompt,
                 )
-                from AgentCrew.modules.agents.tools.ask import (
-                    register as register_ask,
-                    ask_tool_prompt,
-                )
 
                 register_transfer(self.services["agent_manager"], self)
                 self.tool_prompts.append(
                     transfer_tool_prompt(self.services["agent_manager"])
                 )
 
-                # Register the ask tool (always available)
-                register_ask(self)
-                self.tool_prompts.append(ask_tool_prompt())
-
         for tool_name in self.tools:
             if self.services and tool_name in self.services:
                 service = self.services[tool_name]
@@ -634,7 +634,7 @@ Check if `when` condition in <Global_Behavior> or <Project_Behavior> matches, up
     - Skip agent evaluation if user request is when...,[action]... related to adaptive behaviors call `adapt` tool instead.""",
                     },
                 )
-            if self.services.get("memory"):
+            if not self.is_remoting_mode and self.services.get("memory"):
                 memory_headers = self.services["memory"].list_memory_headers(
                     agent_name=self.name
                 )
@@ -642,7 +642,7 @@ Check if `when` condition in <Global_Behavior> or <Project_Behavior> matches, up
                     adaptive_messages["content"].append(
                         {
                             "type": "text",
-                            "text": f"Here are conversations that we have discussed:\n- {'\n- '.join(memory_headers)}",
+                            "text": f"Here are conversations that we have discussed from oldest to latest:\n - {'\n - '.join(memory_headers)}",
                         }
                     )
         if len(adaptive_messages["content"]) > 0:
