@@ -279,7 +279,7 @@ class MessageHandler(Observable):
                     # Notify about response progress
                     if not self.agent.is_streaming():
                         # Delays it a bit when using without stream
-                        time.sleep(0.5)
+                        time.sleep(0.3)
                     self._notify("response_chunk", (chunk_text, assistant_response))
                     if voice_sentence is not None:
                         if (
@@ -321,6 +321,8 @@ class MessageHandler(Observable):
                                     .lstrip("\n")
                                 )
 
+            self.stream_generator = None
+
             # End thinking when break the response stream
             if not end_thinking and start_thinking:
                 self._notify("thinking_completed", thinking_content)
@@ -386,11 +388,6 @@ class MessageHandler(Observable):
 
                 return await self.get_assistant_response()
 
-            self.stream_generator = None
-
-            if thinking_content:
-                self._notify("agent_continue", self.agent.name)
-
             # Add assistant response to messages
             if assistant_response.strip():
                 self._messages_append(
