@@ -22,6 +22,11 @@ class ToolManager:
         self._pending_confirmations = {}  # Store futures for confirmation requests
         self._next_confirmation_id = 0  # ID counter for confirmation requests
         self.yolo_mode = False  # Enable/disable auto-approval mode
+        self.session_overrided_yolo_mode: bool = False
+
+    def get_effective_yolo_mode(self) -> bool:
+        """Determine the effective YOLO mode considering session override."""
+        return self.session_overrided_yolo_mode or self.yolo_mode
 
     def _load_persistent_auto_approved_tools(self):
         """Load persistent auto-approved tools from config."""
@@ -122,7 +127,7 @@ class ToolManager:
 
         if (
             not self.message_handler.is_non_interactive
-            and not self.yolo_mode
+            and not self.get_effective_yolo_mode()
             and tool_name not in self._auto_approved_tools
         ):
             # Request confirmation from the user
@@ -259,7 +264,8 @@ class ToolManager:
     def _post_tool_transfer(self, tool_use, tool_result):
         """Handle post-transfer operations."""
         if (
-            self.message_handler.current_conversation_id
+            self.message_handler.persistent_service
+            and self.message_handler.current_conversation_id
             and self.message_handler.last_assisstant_response_idx >= 0
         ):
             self.message_handler.persistent_service.append_conversation_messages(
@@ -286,7 +292,10 @@ class ToolManager:
                 "content": [{"type": "text", "text": tool_result}],
             }
         )
-        if self.message_handler.current_conversation_id:
+        if (
+            self.message_handler.persistent_service
+            and self.message_handler.current_conversation_id
+        ):
             self.message_handler.persistent_service.append_conversation_messages(
                 self.message_handler.current_conversation_id,
                 [
