@@ -2,7 +2,6 @@ import os
 import sys
 import time
 import uuid
-import queue
 import threading
 import subprocess
 import re
@@ -10,12 +9,11 @@ import atexit
 import hashlib
 from typing import Dict, Any, Optional, Tuple, List
 from datetime import datetime
-from .metric import CommandMetrics
 from .types import CommandState, CommandProcess
 from .constants import (
     MAX_CONCURRENT_COMMANDS,
     MAX_COMMAND_LIFETIME,
-    MAX_OUTPUT_SIZE,
+    MAX_OUTPUT_LINES,
     MAX_COMMANDS_PER_MINUTE,
     MAX_INPUT_SIZE,
     BLOCKED_PATTERNS,
@@ -68,9 +66,6 @@ class CommandExecutionService:
         # Rate limiting (application-wide)
         self._rate_limiter: List[float] = []
 
-        # Metrics
-        self.metrics = CommandMetrics()
-
         # Register cleanup on shutdown
         atexit.register(self.shutdown)
 
@@ -242,40 +237,40 @@ class CommandExecutionService:
     def _reader_thread(
         self,
         stream,
-        output_queue: queue.Queue,
+        output_list: list,
+        output_lock: threading.Lock,
         stop_event: threading.Event,
-        max_size: int,
+        max_lines: int,
     ):
         """
-        Read stream line by line into queue with size enforcement.
+        Read stream line by line into persistent list with rolling buffer.
 
-        Uses sentinel values:
-        - ('data', line): Normal output line
-        - ('eof', None): End of stream
-        - ('error', msg): Error occurred
-        - ('size_limit', None): Output size limit reached
+        When output exceeds max_lines, old lines are removed to keep recent output.
+
+        Args:
+            stream: Process stdout or stderr stream
+            output_list: Persistent list to append output lines
+            output_lock: Threading lock for thread-safe list access
+            stop_event: Event to signal thread stop
+            max_lines: Maximum number of lines to keep (rolling buffer)
         """
-        total_bytes = 0
-
         try:
             for line in iter(stream.readline, b""):
                 if stop_event.is_set():
                     break
 
-                total_bytes += len(line)
-                if total_bytes > max_size:
-                    output_queue.put(("size_limit", None))
-                    logger.warning(f"Output size limit ({max_size} bytes) exceeded")
-                    break
-
                 decoded = line.decode("utf-8", errors="replace")
-                output_queue.put(("data", decoded))
+
+                with output_lock:
+                    output_list.append(decoded)
+
+                    # Keep only recent lines using slice
+                    if len(output_list) > max_lines:
+                        output_list[:] = output_list[-max_lines:]
 
         except Exception as e:
             logger.error(f"Reader thread error: {e}")
-            output_queue.put(("error", str(e)))
         finally:
-            output_queue.put(("eof", None))
             stream.close()
 
     def execute_command(
@@ -371,9 +366,10 @@ class CommandExecutionService:
                 target=self._reader_thread,
                 args=(
                     process.stdout,
-                    cmd_process.output_queue,
+                    cmd_process.stdout_lines,
+                    cmd_process.output_lock,
                     cmd_process.stop_event,
-                    MAX_OUTPUT_SIZE,
+                    MAX_OUTPUT_LINES,
                 ),
                 daemon=True,
                 name=f"stdout-reader-{command_id}",
@@ -383,9 +379,10 @@ class CommandExecutionService:
                 target=self._reader_thread,
                 args=(
                     process.stderr,
-                    cmd_process.error_queue,
+                    cmd_process.stderr_lines,
+                    cmd_process.output_lock,
                     cmd_process.stop_event,
-                    MAX_OUTPUT_SIZE,
+                    MAX_OUTPUT_LINES,
                 ),
                 daemon=True,
                 name=f"stderr-reader-{command_id}",
@@ -405,21 +402,10 @@ class CommandExecutionService:
             cmd_process.exit_code = process.returncode
             cmd_process.transition_to(CommandState.COMPLETING)
 
-            output_lines = []
-            error_lines = []
-
-            while not cmd_process.output_queue.empty():
-                msg_type, data = cmd_process.output_queue.get()
-                if msg_type == "data":
-                    output_lines.append(data)
-
-            while not cmd_process.error_queue.empty():
-                msg_type, data = cmd_process.error_queue.get()
-                if msg_type == "data":
-                    error_lines.append(data)
-
-            output = "".join(output_lines)
-            error_output = "".join(error_lines)
+            # Get output from persistent storage (thread-safe)
+            with cmd_process.output_lock:
+                output = "".join(cmd_process.stdout_lines)
+                error_output = "".join(cmd_process.stderr_lines)
 
             duration = time.time() - start_time
 
@@ -433,7 +419,6 @@ class CommandExecutionService:
                 len(output) + len(error_output),
             )
 
-            self.metrics.record_execution(command, duration, "completed")
             self._cleanup_command_internal(command_id)
 
             result = {
@@ -466,22 +451,20 @@ class CommandExecutionService:
             logger.error(f"Command execution error: {e}")
 
             self._audit_log(command, "error", command_id)
-            self.metrics.record_execution(command, time.time() - start_time, "error")
 
             if command_id in self._instances:
                 self._cleanup_command_internal(command_id)
 
             return {"status": "error", "error": f"Execution failed: {str(e)}"}
 
-    def get_command_status(
-        self, command_id: str, consume_output: bool = True
-    ) -> Dict[str, Any]:
+    def get_command_status(self, command_id: str) -> Dict[str, Any]:
         """
         Check status of running command.
 
+        Output is persistent and will be returned in full on every call.
+
         Args:
             command_id: Command identifier
-            consume_output: If True, drain and return queued output
 
         Returns:
             Dict with status, output, exit_code, elapsed_time
@@ -494,30 +477,11 @@ class CommandExecutionService:
 
         exit_code = cmd_process.process.poll()
 
-        output_lines = []
-        error_lines = []
+        # Get output from persistent storage (thread-safe)
+        with cmd_process.output_lock:
+            output = "".join(cmd_process.stdout_lines)
+            error_output = "".join(cmd_process.stderr_lines)
 
-        if consume_output:
-            while not cmd_process.output_queue.empty():
-                try:
-                    msg_type, data = cmd_process.output_queue.get_nowait()
-                    if msg_type == "data":
-                        output_lines.append(data)
-                    elif msg_type == "size_limit":
-                        output_lines.append("\n[OUTPUT SIZE LIMIT REACHED]\n")
-                except queue.Empty:
-                    break
-
-            while not cmd_process.error_queue.empty():
-                try:
-                    msg_type, data = cmd_process.error_queue.get_nowait()
-                    if msg_type == "data":
-                        error_lines.append(data)
-                except queue.Empty:
-                    break
-
-        output = "".join(output_lines)
-        error_output = "".join(error_lines)
         elapsed = time.time() - cmd_process.start_time
 
         if elapsed > MAX_COMMAND_LIFETIME:
@@ -546,7 +510,6 @@ class CommandExecutionService:
                 duration,
                 len(output) + len(error_output),
             )
-            self.metrics.record_execution(cmd_process.command, duration, "completed")
             self._cleanup_command_internal(command_id)
 
             return {
@@ -690,11 +653,6 @@ class CommandExecutionService:
                             pass
 
                     cmd_process.transition_to(CommandState.KILLED)
-                    self.metrics.record_execution(
-                        cmd_process.command,
-                        time.time() - cmd_process.start_time,
-                        "killed",
-                    )
 
                 except Exception as e:
                     logger.error(f"Process termination error: {e}")
@@ -767,10 +725,6 @@ class CommandExecutionService:
         """
         return self.cleanup_command(command_id)
 
-    def get_metrics(self) -> Dict[str, Any]:
-        """Get command execution metrics"""
-        return self.metrics.get_report()
-
     def shutdown(self):
         """Shutdown service and cleanup all running commands"""
         logger.info("Shutting down CommandExecutionService")
