@@ -227,9 +227,15 @@ class CommandHandlers:
 
         Args:
             file_or_url: Path to local file or URL to fetch agent configuration
+                        Supports @hub/ prefix which converts to https://agentplace.cloud/
         """
         try:
-            # Show download message if URL
+            if file_or_url.startswith("@hub/"):
+                hub_host = os.environ.get(
+                    "AGENTCREW_HUB_HOST", "https://agentplace.cloud"
+                )
+                file_or_url = hub_host.rstrip("/") + "/" + file_or_url[5:]
+
             if file_or_url.startswith(("http://", "https://")):
                 self.console.print(
                     Text(
@@ -346,8 +352,8 @@ class CommandHandlers:
             for behavior_id, behavior_text in project_behaviors.items():
                 project_table.add_row(behavior_id, behavior_text)
 
-                self.console.print(project_table)
-                self.console.print()
+            self.console.print(project_table)
+            self.console.print()
 
     def handle_update_behavior_command(
         self, behavior_id: str, behavior_text: str, scope: str = "global"
