@@ -20,7 +20,6 @@ from .constants import (
     RICH_STYLE_GREEN,
     RICH_STYLE_BLUE,
     RICH_STYLE_YELLOW,
-    RICH_STYLE_GREEN_BOLD,
     RICH_STYLE_YELLOW_BOLD,
     PROMPT_CHAR,
 )
@@ -83,11 +82,17 @@ class ConsoleUI(Observer):
 
         if event == "thinking_started":
             self.ui_effects.stop_loading_animation()  # Stop loading on first chunk
-            self.display_handlers.display_thinking_started(data)  # data is agent_name
+            # self.display_handlers.display_thinking_started(data)  # data is agent_name
         elif event == "thinking_chunk":
-            self.display_handlers.display_thinking_chunk(
-                data
-            )  # data is the thinking chunk
+            self.ui_effects.update_live_display(data, is_thinking=True)
+            # self.display_handlers.display_thinking_chunk(
+            #     data
+            # )  # data is the thinking chunk
+            #
+        elif event == "thinking_completed":
+            self.ui_effects.finish_response(
+                self.ui_effects.updated_text, is_thinking=True
+            )
         elif event == "user_message_created":
             pass
         elif event == "response_chunk":
@@ -178,10 +183,6 @@ class ConsoleUI(Observer):
                 f"{data['agent_name'] if 'agent_name' in data else 'other'} agent"
             )
             self.display_handlers.display_message(transfer_text)
-        elif event == "agent_continue":
-            self.display_handlers.display_message(
-                Text(f"\n🤖 {data.upper()}:", style=RICH_STYLE_GREEN_BOLD)
-            )
         elif event == "jump_performed":
             jump_text = Text(
                 f"🕰️ Jumping to turn {data['turn_number']}...\n",
@@ -189,12 +190,11 @@ class ConsoleUI(Observer):
             )
             preview_text = Text("Conversation rewound to: ", style=RICH_STYLE_YELLOW)
             preview_text.append(data["preview"])
+            self._clear_and_reprint_chat()
 
             self.display_handlers.display_message(jump_text)
             self.display_handlers.display_message(preview_text)
             self.input_handler.set_current_buffer(data["message"])
-        elif event == "thinking_completed":
-            self.display_handlers.display_divider()
         elif event == "file_processing":
             self.ui_effects.stop_loading_animation()  # Stop loading on first chunk
             self.display_handlers.add_file(data["file_path"])
@@ -286,25 +286,14 @@ class ConsoleUI(Observer):
         Signal handler for SIGWINCH.
         This function is called when the terminal window is resized.
         """
-        import os
         import time
 
         if self.input_handler.is_message_processing or self._is_resizing:
             return  # Ignore resize during message processing
         self._is_resizing = True
         time.sleep(0.5)  # brief pause to allow resize to complete
-        os.system("cls" if os.name == "nt" else "printf '\033c'")
-        self.display_handlers.display_loaded_conversation(
-            self.message_handler.streamline_messages, self.message_handler.agent.name
-        )
-        self.display_handlers.print_prompt_prefix(
-            self.message_handler.agent.name,
-            self.message_handler.agent.get_model(),
-            self.message_handler.tool_manager.get_effective_yolo_mode(),
-        )
-
+        self._clear_and_reprint_chat()
         self.display_handlers.print_divider("👤 YOU: ", with_time=True)
-
         prompt = Text(
             PROMPT_CHAR,
             style=RICH_STYLE_BLUE,
@@ -318,6 +307,21 @@ class ConsoleUI(Observer):
         self.console.print(prompt, end="")
         self._is_resizing = False
 
+    def _clear_and_reprint_chat(self):
+        """Clear and reprint the chat display."""
+
+        import os
+
+        os.system("cls" if os.name == "nt" else "printf '\033c'")
+        self.display_handlers.display_loaded_conversation(
+            self.message_handler.streamline_messages, self.message_handler.agent.name
+        )
+        self.display_handlers.print_prompt_prefix(
+            self.message_handler.agent.name,
+            self.message_handler.agent.get_model(),
+            self.message_handler.tool_manager.get_effective_yolo_mode(),
+        )
+
     def start_streaming_response(self, agent_name: str):
         """Start streaming the assistant's response."""
         self.ui_effects.start_streaming_response(agent_name)
