@@ -105,9 +105,9 @@ class InputHandler:
                         file_command = paste_result["content"]
 
                         # Insert the file command into the current buffer
-                        event.current_buffer.insert_text(file_command)
-                        event.current_buffer.validate_and_handle()
-
+                        self._jumped_user_message = event.current_buffer.text
+                        event.current_buffer.reset()
+                        self._input_queue.put(file_command)
                         return
 
                 # For regular text content, use default paste behavior
@@ -163,7 +163,7 @@ class InputHandler:
             else:
                 if (
                     hasattr(self.message_handler, "stream_generator")
-                    and self.message_handler.stream_generator
+                    and not self.message_handler.stop_streaming
                 ):
                     try:
                         self.message_handler.stop_streaming = True
@@ -268,13 +268,13 @@ class InputHandler:
             self._current_prompt_session.app.current_buffer.reset()
             if self._jumped_user_message:
                 self._current_prompt_session.app.current_buffer.insert_text(
-                    self._jumped_user_message
+                    self._jumped_user_message, overwrite=True
                 )
                 self._jumped_user_message = ""
-            if not self.is_message_processing:
-                self.display_handlers.print_divider("👤 YOU: ", with_time=True)
             self._current_prompt_session.message = HTML(PROMPT_CHAR)
             self._current_prompt_session.app.invalidate()
+            if not self.is_message_processing:
+                self.display_handlers.print_divider("👤 YOU: ", with_time=True)
 
     def get_choice_input(self, message: str, values: list[str], default=None) -> str:
         from prompt_toolkit.shortcuts import choice
@@ -345,6 +345,8 @@ class InputHandler:
                 self.message_handler.history_manager.reset_position()
 
                 self._input_queue.put(user_input)
+                self.is_message_processing = True
+                self.display_handlers.print_divider()
 
             except KeyboardInterrupt:
                 # Handle Ctrl+C in input thread
@@ -428,9 +430,6 @@ class InputHandler:
                 # Add None check here
                 if user_input is None:
                     continue
-                self.is_message_processing = True
-
-                self.display_handlers.print_divider()
 
                 if user_input == "__EXIT__":
                     self.console.print(
