@@ -3,6 +3,7 @@ from .system_message import SystemMessageWidget
 from .message_bubble import MessageBubble
 from .history_sidebar import ConversationSidebar, ConversationLoader
 from .tool_widget import ToolWidget
+from .diff_widget import DiffWidget, CompactDiffWidget
 
 __all__ = [
     "TokenUsageWidget",
@@ -11,4 +12,6 @@ __all__ = [
     "ConversationSidebar",
     "ConversationLoader",
     "ToolWidget",
+    "DiffWidget",
+    "CompactDiffWidget",
 ]
