@@ -1,11 +1,21 @@
 from .types import Model, SampleParam
 
 _ANTHROPIC_MODELS = [
+    Model(
+        id="claude-opus-4-5",
+        provider="claude",
+        name="Claude 4.5 Opus",
+        description="Premium model combining maximum intelligence with practical performance",
+        capabilities=["thinking", "tool_use", "vision", "stream"],
+        default=False,
+        input_token_price_1m=5.0,
+        output_token_price_1m=25.0,
+    ),
     Model(
         id="claude-opus-4-1",
         provider="claude",
         name="Claude 4.1 Opus",
-        description="Anthropic's most capable and intelligent model yet. Claude Opus 4 sets new standards in complex reasoning and advanced coding",
+        description="Exceptional model for specialized reasoning tasks",
         capabilities=["thinking", "tool_use", "vision", "stream"],
         default=False,
         input_token_price_1m=15.0,
@@ -15,7 +25,7 @@ _ANTHROPIC_MODELS = [
         id="claude-sonnet-4-5",
         provider="claude",
         name="Claude 4.5 Sonnet",
-        description="Anthropic's best coding model in the world",
+        description="Our smartest model for complex agents and coding",
         capabilities=["thinking", "tool_use", "vision", "stream"],
         default=False,
         input_token_price_1m=3.0,
@@ -25,7 +35,7 @@ _ANTHROPIC_MODELS = [
         id="claude-haiku-4-5",
         provider="claude",
         name="Claude 4.5 Haiku",
-        description="Anthropic's fastest model",
+        description="Our fastest model with near-frontier intelligence",
         capabilities=["tool_use", "vision", "stream", "thinking"],
         input_token_price_1m=0.8,
         output_token_price_1m=4.0,
@@ -80,6 +90,15 @@ _OPENAI_MODELS = [
         input_token_price_1m=0.25,
         output_token_price_1m=2.0,
     ),
+    Model(
+        id="gpt-5.1-codex-max",
+        provider="openai",
+        name="GPT-5.1 Codex Max",
+        description="GPT‑5.1-Codex-Max is purpose-built for agentic coding",
+        capabilities=["tool_use", "vision", "thinking", "stream", "structured_output"],
+        input_token_price_1m=1.25,
+        output_token_price_1m=10.0,
+    ),
     Model(
         id="gpt-4.1-mini",
         provider="openai",
@@ -430,6 +449,18 @@ _GITHUB_COPILOT_MODELS = [
         output_token_price_1m=0.0,
         endpoint="response",
     ),
+    Model(
+        id="gpt-5.1-codex-max",
+        provider="copilot_response",
+        name="GPT 5.1 Codex Max",
+        description="",
+        capabilities=["tool_use", "vision", "stream", "structured_output"],
+        default=False,
+        max_context_token=400_000,
+        input_token_price_1m=0.0,
+        output_token_price_1m=0.0,
+        endpoint="response",
+    ),
     Model(
         id="gpt-5-mini",
         provider="github_copilot",
@@ -515,6 +546,16 @@ _GITHUB_COPILOT_MODELS = [
         input_token_price_1m=0.0,
         output_token_price_1m=0.0,
     ),
+    Model(
+        id="claude-opus-4.5",
+        provider="github_copilot",
+        name="Claude Opus 4.5 (Preview)",
+        description="",
+        capabilities=["tool_use", "vision", "stream"],
+        default=False,
+        input_token_price_1m=0.0,
+        output_token_price_1m=0.0,
+    ),
 ]
 AVAILABLE_MODELS = (
     _ANTHROPIC_MODELS
