@@ -256,6 +256,62 @@ class ContextPersistenceService:
 
         return history
 
+    def store_conversation_metadata(
+        self, conversation_id: str, metadata: Dict[str, Any]
+    ) -> bool:
+        """
+        Stores metadata for a conversation as a separate JSON file.
+
+        Args:
+            conversation_id: The ID of the conversation.
+            metadata: Dictionary containing metadata to store.
+
+        Returns:
+            True if successful, False otherwise.
+
+        Raises:
+            ValueError: If metadata is not a dictionary.
+            IOError, TypeError, OSError: If writing fails.
+        """
+        if not isinstance(metadata, dict):
+            raise ValueError("Metadata must be a dictionary")
+
+        file_path = os.path.join(
+            self.conversations_dir, f"{conversation_id}.metadata.json"
+        )
+
+        try:
+            self._write_json_file(file_path, metadata)
+            logger.info(f"INFO: Stored metadata for conversation: {conversation_id}")
+            return True
+        except Exception as e:
+            logger.error(f"ERROR: Failed to store metadata for {conversation_id}: {e}")
+            return False
+
+    def get_conversation_metadata(self, conversation_id: str) -> Dict[str, Any]:
+        """
+        Retrieves metadata for a conversation.
+
+        Args:
+            conversation_id: The ID of the conversation.
+
+        Returns:
+            Dictionary containing metadata, or empty dict if file not found.
+        """
+        file_path = os.path.join(
+            self.conversations_dir, f"{conversation_id}.metadata.json"
+        )
+
+        metadata = self._read_json_file(file_path, default_value={})
+
+        if not isinstance(metadata, dict):
+            logger.warning(
+                f"WARNING: Metadata for {conversation_id} was not a dictionary. Returning empty dict."
+            )
+            return {}
+
+        return metadata
+
     def list_conversations(self) -> List[Dict[str, Any]]:
         """
         Scans the conversations directory and returns metadata for available conversations.
@@ -273,7 +329,9 @@ class ContextPersistenceService:
             # listdir raises OSError if the directory is invalid
             filenames = os.listdir(self.conversations_dir)
             for filename in filenames:
-                if filename.endswith(".json"):
+                if filename.endswith(".json") and not filename.endswith(
+                    ".metadata.json"
+                ):
                     conversation_id = filename[:-5]  # Remove .json extension
                     file_path = os.path.join(self.conversations_dir, filename)
                     try:
@@ -455,7 +513,9 @@ class ContextPersistenceService:
             logger.error(f"ERROR: Failed to store adaptive behavior: {e}")
             return False
 
-    def remove_adaptive_behavior(self, agent_name: str, behavior_id: str) -> bool:
+    def remove_adaptive_behavior(
+        self, agent_name: str, behavior_id: str, is_local: bool = False
+    ) -> bool:
         """
         Removes a specific adaptive behavior for an agent.
 
@@ -466,9 +526,13 @@ class ContextPersistenceService:
         Returns:
             True if successful or behavior didn't exist, False on error.
         """
-        adaptive_data = self._read_json_file(
-            self.adaptive_behaviors_file_path, default_value={}
+
+        adaptive_file_path = (
+            self.adaptive_behaviors_local_path
+            if is_local
+            else self.adaptive_behaviors_file_path
         )
+        adaptive_data = self._read_json_file(adaptive_file_path, default_value={})
 
         if not isinstance(adaptive_data, dict):
             logger.warning("WARNING: Adaptive behaviors file was not a dictionary.")
@@ -482,7 +546,7 @@ class ContextPersistenceService:
                 del adaptive_data[agent_name]
 
             try:
-                self._write_json_file(self.adaptive_behaviors_file_path, adaptive_data)
+                self._write_json_file(adaptive_file_path, adaptive_data)
                 logger.info(
                     f"INFO: Removed adaptive behavior '{behavior_id}' for agent '{agent_name}'"
                 )
